@@ -1,20 +1,25 @@
 """ GeckoLib automation interface """
 
-from .base import GeckoAutomationBase
+from .base import GeckoAutomationBase, GeckoAutomationFacadeBase
 from .blower import GeckoBlower
+from .button import GeckoButton
 from .facade import GeckoFacade
+from .async_facade import GeckoAsyncFacade
 from .heater import GeckoWaterHeater
 from .keypad import GeckoKeypad
 from .light import GeckoLight
 from .pump import GeckoPump
 from .sensors import GeckoSensor, GeckoBinarySensor
-from .switches import GeckoSwitch
+from .switch import GeckoSwitch
 from .watercare import GeckoWaterCare
 
 __all__ = [
+    "GeckoAutomationFacadeBase",
     "GeckoAutomationBase",
     "GeckoBlower",
+    "GeckoButton",
     "GeckoFacade",
+    "GeckoAsyncFacade",
     "GeckoWaterHeater",
     "GeckoKeypad",
     "GeckoLight",
