@@ -2,17 +2,17 @@
 
 import logging
 
-from .base import GeckoAutomationBase
+from .base import GeckoAutomationFacadeBase
 from .sensors import GeckoSensor
 
 logger = logging.getLogger(__name__)
 
 
-class GeckoPump(GeckoAutomationBase):
-    """ Pumps are similar to switches, but might have variable speeds too """
+class GeckoPump(GeckoAutomationFacadeBase):
+    """Pumps are similar to switches, but might have variable speeds too"""
 
     def __init__(self, facade, key, props, user_demand):
-        """ props is a tuple of (name, keypad_button, state_key, device_class) """
+        """props is a tuple of (name, keypad_button, state_key, device_class)"""
         super().__init__(facade, props[0], key)
         self.ui_key = key
         self._state_sensor = GeckoSensor(
@@ -40,6 +40,17 @@ class GeckoPump(GeckoAutomationBase):
                 "Exception handling setting %s=%s", self._user_demand["demand"], mode
             )
 
+    async def async_set_mode(self, mode):
+        try:
+            logger.debug("%s async set mode %s", self.name, mode)
+            await self.facade.spa.accessors[
+                self._user_demand["demand"]
+            ].async_set_value(mode)
+        except Exception:  # pylint: disable=broad-except
+            logger.exception(
+                "Exception handling setting %s=%s", self._user_demand["demand"], mode
+            )
+
     def __str__(self):
         return f"{self.name}: {self._state_sensor.state}"
 
