@@ -9,7 +9,6 @@ class GeckoConstants:
     functions documented behaviour might not be here, e.g. 'rw' as a parameter to open()
     """
 
-    INCLUDE_DUMMY_SPA = False
     INTOUCH2_PORT = 10022
     MAX_PACKET_SIZE = 8192
     # Mininum time to wait for initial spa discovery even if one spa has responded
@@ -18,40 +17,27 @@ class GeckoConstants:
     DISCOVERY_TIMEOUT_IN_SECONDS = 10
     # Maximum time to wait for full connection for a responding spa
     CONNECTION_TIMEOUT_IN_SECONDS = 45
+    # Time between task tidyup checks
+    TASK_TIDY_FREQUENCY_IN_SECONDS = 5
     PING_TIMEOUT_IN_SECONDS = 4
-    PING_FREQUENCY_IN_SECONDS = 15
-    PING_DEVICE_NOT_RESPONDING_TIMEOUT = 60
+    PING_FREQUENCY_IN_SECONDS = 2
+    PING_DEVICE_NOT_RESPONDING_TIMEOUT = 10
     FACADE_UPDATE_FREQUENCY_IN_SECONDS = 30
+    FACADE_HEALTH_MONITOR_DUTY_CYCLE_IN_SECONDS = 10
+    SPA_PACK_REFRESH_FREQUENCY_IN_SECONDS = 30
+    CONNECTION_STEP_PAUSE_IN_SECONDS = 0  # Time between connection steps
+    MAX_RF_ERRORS_BEFORE_HALT = 50
 
     BROADCAST_ADDRESS = "<broadcast>"
     MESSAGE_ENCODING = "latin1"
     FORMAT_CLIENT_IDENTIFIER = "IOS{0}"
 
-    SPA_PACK_STRUCT_FILE = "SpaPackStruct.xml"
-    SPA_PACK_STRUCT_URL = "http://intouch.geckoal.com/gecko/prod/SpaPackStruct.xml"
     # XPaths and attributes for SpaPackStruct
-    SPA_PACK_REVISION_XPATH = "./SpaPackStruct/FileRevision"
-    SPA_PACK_REVISION_ATTRIB = "Number"
-    SPA_PACK_PLATEFORM_XPATH = "./Plateform"
-    SPA_PACK_NAME_ATTRIB = "Name"
-    SPA_PACK_CONFIG_XPATH = "./ConfigStructures/ConfigStructure[@LibRev='{0}']"
-    SPA_PACK_LOG_XPATH = "./LogStructures/LogStructure[@LibRev='{0}']"
-    SPA_PACK_STRUCT_POS_ATTRIB = "Pos"
-    SPA_PACK_STRUCT_TYPE_ATTRIB = "Type"
-    SPA_PACK_STRUCT_BITPOS_ATTRIB = "BitPos"
-    SPA_PACK_STRUCT_ITEMS_ATTRIB = "Items"
-    SPA_PACK_STRUCT_SIZE_ATTRIB = "Size"
     SPA_PACK_STRUCT_BYTE_TYPE = "Byte"
     SPA_PACK_STRUCT_WORD_TYPE = "Word"
     SPA_PACK_STRUCT_TIME_TYPE = "Time"
-    SPA_PACK_STRUCT_MAXITEMS_ATTRIB = "MaxItems"
     SPA_PACK_STRUCT_BOOL_TYPE = "Bool"
     SPA_PACK_STRUCT_ENUM_TYPE = "Enum"
-    SPA_PACK_STRUCT_POS_ELEMENTS_XPATH = ".//*[@Pos]"
-    SPA_PACK_STRUCT_WORD_TYPE_ELEMENTS_XPATH = './/*[@Type="Word"]'
-    SPA_PACK_STRUCT_BEGIN_ATTRIB = "Begin"
-    SPA_PACK_STRUCT_END_ATTRIB = "End"
-    SPA_PACK_STRUCT_READ_WRITE_ATTRIB = "RW"
     # Accessor keys for SpaPackStruct
     KEY_PACK_TYPE = "PackType"
     KEY_PACK_CONFIG_ID = "PackConfID"
@@ -106,14 +92,6 @@ class GeckoConstants:
     KEYPAD_ECOMODE = 0
 
     # Pack outputs
-    PACK_OUTPUTS_XPATHS = [
-        './HCOutputConfig/*[@Type="Enum"]',
-        './LCOutputConfig/*[@Type="Enum"]',
-        './LVOutputConfig/*[@Type="Enum"]',
-    ]
-    SPA_PACK_DEVICE_XPATH = "./DeviceStatus/*"
-    SPA_PACK_USER_DEMANDS = "./UserDemands/*"
-
     DEVICE_CLASS_PUMP = "PUMP"
     DEVICE_CLASS_BLOWER = "BLOWER"
     DEVICE_CLASS_LIGHT = "LIGHT"
