@@ -9,15 +9,17 @@ from .protocol import (
     GeckoConfigFileProtocolHandler,
     GeckoStatusBlockProtocolHandler,
     GeckoPartialStatusBlockProtocolHandler,
+    GeckoAsyncPartialStatusBlockProtocolHandler,
     GeckoWatercareProtocolHandler,
+    GeckoWatercareErrorHandler,
     GeckoUpdateFirmwareProtocolHandler,
     GeckoRemindersProtocolHandler,
     GeckoPackCommandProtocolHandler,
     GeckoRFErrProtocolHandler,
+    GeckoUnhandledProtocolHandler,
 )
 from .observable import Observable
 
-# from .spapack import GeckoSpaPack
 from .accessor import (
     GeckoStructAccessor,
     GeckoByteStructAccessor,
@@ -28,7 +30,10 @@ from .accessor import (
     GeckoTempStructAccessor,
 )
 from .spastruct import GeckoStructure
-from .udp_socket import GeckoUdpProtocolHandler, GeckoUdpSocket
+from .async_spastruct import GeckoAsyncStructure
+from .udp_protocol_handler import GeckoUdpProtocolHandler
+from .udp_socket import GeckoUdpSocket
+from .async_udp_protocol import GeckoAsyncUdpProtocol
 
 __all__ = [
     "GeckoHelloProtocolHandler",
@@ -39,15 +44,18 @@ __all__ = [
     "GeckoConfigFileProtocolHandler",
     "GeckoStatusBlockProtocolHandler",
     "GeckoPartialStatusBlockProtocolHandler",
+    "GeckoAsyncPartialStatusBlockProtocolHandler",
     "GeckoWatercareProtocolHandler",
     "GeckoUpdateFirmwareProtocolHandler",
     "GeckoRemindersProtocolHandler",
     "GeckoRFErrProtocolHandler",
     "GeckoPackCommandProtocolHandler",
+    "GeckoUnhandledProtocolHandler",
     "Observable",
     #
     # "GeckoSpaPack",
     "GeckoStructure",
+    "GeckoAsyncStructure",
     "GeckoStructAccessor",
     "GeckoByteStructAccessor",
     "GeckoWordStructAccessor",
@@ -57,4 +65,5 @@ __all__ = [
     "GeckoTempStructAccessor",
     "GeckoUdpProtocolHandler",
     "GeckoUdpSocket",
+    "GeckoAsyncUdpProtocol",
 ]
