@@ -12,9 +12,11 @@ from .rferr import GeckoRFErrProtocolHandler
 from .statusblock import (
     GeckoStatusBlockProtocolHandler,
     GeckoPartialStatusBlockProtocolHandler,
+    GeckoAsyncPartialStatusBlockProtocolHandler,
 )
+from .unhandled import GeckoUnhandledProtocolHandler
 from .version import GeckoVersionProtocolHandler
-from .watercare import GeckoWatercareProtocolHandler
+from .watercare import GeckoWatercareProtocolHandler, GeckoWatercareErrorHandler
 
 __all__ = [
     # From hello
@@ -32,8 +34,10 @@ __all__ = [
     # From statusblock
     "GeckoStatusBlockProtocolHandler",
     "GeckoPartialStatusBlockProtocolHandler",
+    "GeckoAsyncPartialStatusBlockProtocolHandler",
     # From watercare
     "GeckoWatercareProtocolHandler",
+    "GeckoWatercareErrorHandler",
     # From firmware
     "GeckoUpdateFirmwareProtocolHandler",
     # From reminders
@@ -42,4 +46,6 @@ __all__ = [
     "GeckoRFErrProtocolHandler",
     # From packcommand
     "GeckoPackCommandProtocolHandler",
+    # From unhandled
+    "GeckoUnhandledProtocolHandler",
 ]
