@@ -5,8 +5,6 @@ import threading
 import time
 import importlib
 
-from geckolib.driver.protocol.rferr import GeckoRFErrProtocolHandler
-
 from .const import GeckoConstants
 from .driver import (
     GeckoUdpSocket,
@@ -19,50 +17,14 @@ from .driver import (
     GeckoStatusBlockProtocolHandler,
     GeckoPartialStatusBlockProtocolHandler,
     GeckoPackCommandProtocolHandler,
+    GeckoRFErrProtocolHandler,
     # Rest
     GeckoStructure,
 )
-from .automation import GeckoFacade
 
 logger = logging.getLogger(__name__)
 
 
-class GeckoSpaDescriptor:
-    """ A descriptor class for spas that have been discovered on the network """
-
-    def __init__(
-        self,
-        client_identifier: bytes,
-        spa_identifier: bytes,
-        spa_name: str,
-        sender: tuple,
-    ):
-        self.client_identifier = client_identifier
-        self.identifier = spa_identifier
-        self.name = spa_name
-        self.ipaddress, self.port = sender
-
-    def get_facade(self, wait_for_connection=True):
-        """Get an automation facade to interact with the spa described
-        by this class"""
-        facade = GeckoFacade(GeckoSpa(self).start_connect())
-        if wait_for_connection:
-            while not facade.is_connected:
-                facade.wait(0.1)
-        return facade
-
-    @property
-    def identifier_as_string(self):
-        return self.identifier.decode(GeckoConstants.MESSAGE_ENCODING)
-
-    @property
-    def destination(self):
-        return (self.ipaddress, self.port)
-
-    def __repr__(self):
-        return f"{self.name}({self.identifier_as_string})"
-
-
 class GeckoSpa(GeckoUdpSocket):
     """
     GeckoSpa class manages an instance of a spa, and is the main point of contact for
@@ -77,10 +39,10 @@ class GeckoSpa(GeckoUdpSocket):
         self.on_connected = None
         self.is_in_error = False
 
-        self.add_receive_handler(GeckoPacketProtocolHandler())
+        self.add_receive_handler(GeckoPacketProtocolHandler(socket=self))
         self.add_receive_handler(
             GeckoPartialStatusBlockProtocolHandler(
-                on_handled=self._on_partial_status_update
+                self, on_handled=self._on_partial_status_update
             )
         )
         self._last_ping = time.monotonic()
@@ -108,7 +70,7 @@ class GeckoSpa(GeckoUdpSocket):
         self.new_config_class = None
 
     def complete(self):
-        """ Complete the use of this spa class """
+        """Complete the use of this spa class"""
         super().close()
         self._ping_thread.join()
 
@@ -116,7 +78,7 @@ class GeckoSpa(GeckoUdpSocket):
     def accessors(self):
         return self.struct.accessors
 
-    def _on_partial_status_update(self, handler, socket, sender):
+    def _on_partial_status_update(self, handler, sender):
         for change in handler.changes:
             self.struct.replace_status_block_segment(change[0], change[1])
         else:
@@ -139,7 +101,7 @@ class GeckoSpa(GeckoUdpSocket):
             self.sendparms,
         )
 
-    def _on_config_received(self, handler, socket, sender):
+    def _on_config_received(self, handler, sender):
 
         # Stash the config and log structure declarations
         self.config_version = handler.config_version
@@ -196,24 +158,24 @@ class GeckoSpa(GeckoUdpSocket):
         self.struct.retry_request(
             self,
             GeckoStatusBlockProtocolHandler.full_request(
-                socket.get_and_increment_sequence_counter(), parms=sender
+                self.get_and_increment_sequence_counter(), parms=sender
             ),
             sender,
         )
 
-    def _on_channel_received(self, handler, socket, sender):
+    def _on_channel_received(self, handler, sender):
         self.channel = handler.channel
         self.signal = handler.signal_strength
         logger.debug("Got channel %s/%s, now get config", self.channel, self.signal)
         config_file_handler = GeckoConfigFileProtocolHandler.request(
-            socket.get_and_increment_sequence_counter(),
+            self.get_and_increment_sequence_counter(),
             parms=sender,
             on_handled=self._on_config_received,
         )
-        socket.add_receive_handler(config_file_handler)
-        socket.queue_send(config_file_handler, sender)
+        self.add_receive_handler(config_file_handler)
+        self.queue_send(config_file_handler, sender)
 
-    def _on_version_received(self, handler, socket, sender):
+    def _on_version_received(self, handler, sender):
         self.intouch_version_en = "{0} v{1}.{2}".format(
             handler.en_build, handler.en_major, handler.en_minor
         )
@@ -230,15 +192,15 @@ class GeckoSpa(GeckoUdpSocket):
             parms=sender,
             on_handled=self._on_channel_received,
         )
-        socket.add_receive_handler(get_channel_handler)
-        socket.queue_send(
+        self.add_receive_handler(get_channel_handler)
+        self.queue_send(
             get_channel_handler,
             sender,
         )
 
     @property
     def revision(self):
-        """ Get the revision of the spa pack structure used to generate the pack modules """
+        """Get the revision of the spa pack structure used to generate the pack modules"""
         return self.new_pack_class.revision
 
     @property
@@ -250,11 +212,11 @@ class GeckoSpa(GeckoUdpSocket):
             self.descriptor.client_identifier,
         )
 
-    def _on_ping_response(self, handler, socket, sender):
+    def _on_ping_response(self, handler, sender):
         self._last_ping = time.monotonic()
 
     def start_connect(self):
-        """ Connect to the in.touch2 module """
+        """Connect to the in.touch2 module"""
         self._connection_started = time.monotonic()
         # Identify self to the intouch module
         self.open()
@@ -306,7 +268,7 @@ class GeckoSpa(GeckoUdpSocket):
         logger.info("Spa is now connected")
 
     def _ping_thread_func(self):
-        """ Ping thread function """
+        """Ping thread function"""
         logger.info("Ping thread started, %r", self.isopen)
         while self.isopen:
             self.queue_send(self._ping_handler, self.sendparms)
@@ -323,7 +285,7 @@ class GeckoSpa(GeckoUdpSocket):
         logger.info("Ping thread finished")
 
     def get_buttons(self):
-        """ Get a list of buttons that can be pressed """
+        """Get a list of buttons that can be pressed"""
         return [button[0] for button in GeckoConstants.BUTTONS]
 
     @property
@@ -339,7 +301,7 @@ class GeckoSpa(GeckoUdpSocket):
         return False
 
     def refresh(self):
-        """ Refresh the live spa data block """
+        """Refresh the live spa data block"""
         if not self.is_connected:
             logger.debug("Can't refresh as we're not connected yet")
             return
@@ -355,7 +317,7 @@ class GeckoSpa(GeckoUdpSocket):
         )
 
     def press(self, keypad):
-        """ Simulate a button press """
+        """Simulate a button press"""
         self.add_receive_handler(GeckoPackCommandProtocolHandler())
         self.queue_send(
             GeckoPackCommandProtocolHandler.keypress(
